@@ -8,15 +8,18 @@ import os
 
 import mmap
 import time
+import sys
 
 MMAPFILE = os.path.expanduser("~/.config/flashcam/mmapfile")
+MMAPSIZE = 1000
 
 
 # -------------------------------------------------------------------------
 
 def mmcreate(filename=MMAPFILE):
+
     with open(filename, "w") as f:
-        f.write("-"*100)
+        f.write("-"*MMAPSIZE)
 
 
 def mmwrite(text, filename = MMAPFILE):
@@ -25,6 +28,12 @@ def mmwrite(text, filename = MMAPFILE):
     """
     if not os.path.exists(filename):
         mmcreate(filename)
+    else:
+        file_size = os.path.getsize( MMAPFILE )
+        print(f"! File Size IS== {file_size}, should be {MMAPSIZE} ")
+        if file_size!=MMAPSIZE:
+            sys.exit(0)
+
     with open(filename, mode="r+", encoding="utf8") as file_obj:
         with mmap.mmap(file_obj.fileno(), length=0, access=mmap.ACCESS_WRITE, offset=0) as mmap_obj:
             #print(" WRITING: ",text)
@@ -38,20 +47,53 @@ def mmwrite(text, filename = MMAPFILE):
 # -------------------------------------------------------------------------
 
 def mmread(filename = MMAPFILE):
-    with open(filename, mode="r", encoding="utf8") as file_obj:
-        with mmap.mmap(file_obj.fileno(), length=0, access=mmap.ACCESS_READ) as mmap_obj:
-            text = mmap_obj.read()
-            print("READTEXT =",text)
+    """
+TO DEBUG ONLY
+    """
+    print(filename)
+    print(filename)
+    print(filename)
+    print(filename)
+    print(filename)
+#    with open(filename, mode="r", encoding="utf8") as file_obj:
+#        with mmap.mmap(file_obj.fileno(), length=0, access=mmap.ACCESS_READ) as mmap_obj:
+#            text = mmap_obj.read()
+#            print("READTEXT =",text)
+
+    with open(filename, mode="r+", encoding="utf8") as file_obj:
+        with mmap.mmap(file_obj.fileno(), length=0, access=mmap.ACCESS_WRITE, offset=0) as mmap_obj:
+            text = mmap_obj.read().decode("utf8").strip()
+            print(text)
+            print(text)
+            print(text)
+            print(text)
+            return text
+
+
 
 def mmread_n_clear(  filename = MMAPFILE ):
     """
     read and clear  filename
     """
+    if os.path.exists(filename):
+        file_size = os.path.getsize( MMAPFILE )
+        if int(file_size) != int(MMAPSIZE):
+            print(f"! File Size == {file_size}, should be {MMAPSIZE}")
+            print(f"! File Size == {file_size}, should be {MMAPSIZE}")
+            print(f"! File Size == {file_size}, should be {MMAPSIZE}")
+            print(f"! File Size == {file_size}, should be {MMAPSIZE}")
+            print(f"! File Size == {file_size}, should be {MMAPSIZE}")
+            os.remove( MMAPFILE )
+            #sys.exit(0)
+            mmcreate(filename)
+
     if not os.path.exists(filename):
         return  "xxxxxx","1"
+
+
     with open(filename, mode="r+", encoding="utf8") as file_obj:
         with mmap.mmap(file_obj.fileno(), length=0, access=mmap.ACCESS_WRITE, offset=0) as mmap_obj:
-            text = mmap_obj.read().decode("utf8")
+            text = mmap_obj.read().decode("utf8").strip()
             # print("READTEXT: ",text)
 
 
@@ -61,12 +103,16 @@ def mmread_n_clear(  filename = MMAPFILE ):
             else:
                 response = text.split("*")[0]
                 response = f"{response.split()[0].strip()}",f"{response.split()[1].strip()}"
-                print("i... returning ", response)
-                print("i... returning ", response)
-                print("i... returning ", response)
+                print("i... mmapread'nclear returning ", response)
+                print("i... mmapread'nclear returning ", response)
+                print("i... mmapread'nclear returning ", response)
 
             text = "*"*50
             # print("CLEARING: ",text)
+
+
+
+            mmap_obj[:MMAPSIZE] = str(" "*MMAPSIZE).encode("utf8")
             mmap_obj[:len(text)] = str(text).encode("utf8")
             mmap_obj.flush()
             return response
