@@ -1038,6 +1038,15 @@ def display2(videodev, save = False,
                     if (not frame is None) and (rpi_name!="") and (key == ord('l')): #>
                         cross[0]+=5
 
+                    if (not frame is None) and (rpi_name!="") and (key == ord('H')): #<
+                        cross[0]-=15
+                    if (not frame is None) and (rpi_name!="") and (key == ord('J')): #v
+                        cross[1]+=15
+                    if (not frame is None) and (rpi_name!="") and (key == ord('K')): #^
+                        cross[1]-=15
+                    if (not frame is None) and (rpi_name!="") and (key == ord('L')): #>
+                        cross[0]+=15
+
 
 
                 if (not frame is None) and (rpi_name!="") and (key == ord('n')):
@@ -1081,9 +1090,11 @@ def display2(videodev, save = False,
 
 
 
-                #---------------- trackers-------------------------------------------
+                #---------------- trackers--------------- t T u----------------------------
+                #if (not frame is None) and (rpi_name!="") and (  (key == ord('t')) or (key == ord('T')) ) :
+                allow_tracker = False
 
-                if (not frame is None) and (rpi_name!="") and (key == ord('t')):
+                if (allow_tracker) and (not frame is None) and (rpi_name!="") and (key == ord('t')):
                     print("t PRESSED! - track" ,tracker1)
                     tracker1 = cv2.TrackerCSRT_create() # KCF GOTURN MIL
                     bbox = cv2.selectROI(frame)
@@ -1108,7 +1119,7 @@ def display2(videodev, save = False,
 
                         # orb = cv2.ORB_create() # I dont use now
 
-                if (not frame is None) and (rpi_name!="") and (key == ord('T')):
+                if  (allow_tracker) and (not frame is None) and (rpi_name!="") and (key == ord('T')):
                     print("t PRESSED! - track" ,tracker2)
                     tracker2 = cv2.TrackerKCF_create() # KCF GOTURN MIL
                     bbox2 = cv2.selectROI(frame)
