@@ -99,15 +99,21 @@ cross_dx, cross_dy = 0,0
 cross_on = False
 zoom2_on = 1
 
+save_fg = False
+mix_fg = False
 save_bg = False
+sub_bg = False
+
+frame_fg = None
+frame_fg2 = None
 frame_bg = None
 frame_bg2 = None
 frame_mask = None
 frame_mask_inv = None
-sub_bg = False
 
 # background path
 BGFILE = os.path.expanduser('~/.config/flashcam/background.jpg')
+FGFILE = os.path.expanduser('~/.config/flashcam/foreground.jpg')
 
 
 
@@ -183,17 +189,29 @@ setInterval(doDate, 200);
 <tr>
 <td>
    <button style="width:100%" name="savebg" value="SAVEBG">saveBG</button>
+    <button style="width:100%" name="savefg" value="SAVEFG">saveFG</button>
 </td>
  <td align="left" rowspan="2">
     <img src="{{url_bg}}" alt="Smiley face"  height="120" width="160" />
  </td>
+ <td align="left" rowspan="2">
+    <img src="{{url_fg}}" alt="Smiley face"  height="120" width="160" />
+ </td>
+
+
  <td>
    <button style="width:100%" name="timelaps" value="TIMELAPS">LAPS</button> <input type = "text" name = "timelaps_input" size="5"  placeholder="0" />
  </td>
 </tr>
+
+
+
+
+
 <tr>
  <td>
     <button style="width:100%" name="subbg" value="SUBBG">subBG</button>
+    <button style="width:100%" name="mixfg" value="MIXFG">mixFG</button>
  </td>
  <td> </td>
  <td>
@@ -207,6 +225,10 @@ setInterval(doDate, 200);
 </tr>
 </table>
 
+
+
+
+
 <hr>
       <button style="width:3%" name="speedx" value="SPEEDX">dX</button>
     <input type = "text" name = "inputx"  size="5" />
@@ -263,7 +285,7 @@ def crossonw( img,  dix, diy):
 @auth.verify_password
 @app.route("/cross", methods=['GET', 'POST'])
 def cross():
-    global cross_dx, cross_dy, cross_on, save_bg, sub_bg, zoom2_on
+    global cross_dx, cross_dy, cross_on, save_bg, save_fg, mix_fg, sub_bg, zoom2_on
 
     # i will read it from file
     crocfg = os.path.expanduser("~/.config/flashcam/cross.txt")
@@ -280,11 +302,27 @@ def cross():
             save_bg = True
             mmwrite(f"save_background {save_bg}" )
 
+        if request.form.get('savefg') == 'SAVEFG':
+            print("i... saving FG" )
+            print("i... saving FG" )
+            print("i... saving FG" )
+            print("i... saving FG" )
+            print("i... saving FG" )
+            print("i... saving FG" )
+            save_fg = True
+            mmwrite(f"save_foreground {save_fg}" )
+
         if request.form.get('subbg') == 'SUBBG':
             print("i... substracting  BG" )
             sub_bg = not( sub_bg)
             mmwrite(f"substract_background {sub_bg}" )
 
+        if request.form.get('mixfg') == 'MIXFG':
+            print("i... mixing FG" )
+            mix_fg = not( mix_fg)
+            mmwrite(f"mix_foreground {mix_fg}" )
+
+
         if request.form.get('accum') == 'ACCUM':
             accum = request.form.get('accumtxt')
             try:
@@ -461,8 +499,9 @@ def cross():
     logthis( " / remote xreal= "+remote_ip )
     url = url_for('video')
     url_bg = url_for('background')
+    url_fg = url_for('foreground')
     #time.sleep(0.5)
-    return render_template_string(index_page, url=url, url_bg  = url_bg)
+    return render_template_string(index_page, url=url, url_bg  = url_bg, url_fg  = url_fg)
 
 
 
@@ -509,7 +548,8 @@ def index():
     url = url_for('video')
     print(url)
     url_bg = url_for('background')
-    return render_template_string(index_page, url=url, url_bg  = url_bg)
+    url_fg = url_for('foreground')
+    return render_template_string(index_page, url=url, url_bg  = url_bg, url_fg  = url_fg)
 
 @app.route('/refresh30')
 @auth.login_required
@@ -522,16 +562,44 @@ def index30():
     url = url_for('video')
     print(url)
     url_bg = url_for('background')
-    return render_template_string(index_page_refresh30, url=url, url_bg  = url_bg)
+    url_fg = url_for('foreground')
+    return render_template_string(index_page_refresh30, url=url, url_bg  = url_bg, url_fg  = url_fg)
 
 
 #('index.html')
 
+@app.route('/foreground')
+@auth.login_required
+def foreground():
+    global  save_bg, frame_bg, frame_bg2, save_fg, frame_fg, frame_fg2, frame_mask, frame_mask_inv #, BGFILE
+
+    if os.path.exists( FGFILE):
+        blank = cv2.imread( FGFILE )
+        # print( blank )
+        # # frame_bg = cv2.imdecode(blank, cv2.IMREAD_COLOR)
+        frame_fg = blank.copy() # propagate to the system
+        r, jpg = cv2.imencode('.jpg', blank)
+        print("OLD FOREGROUND IMAGE FOUND",r, frame_fg.shape)
+    else:
+        blank = np.zeros((480,640,3), np.uint8)
+        frame_fg = blank.copy() # propagate to the system
+        #frame = cv2.imdecode(blank, cv2.IMREAD_COLOR)
+        r, jpg = cv2.imencode('.jpg', blank)
+        print("NO FOREGROUND - black image",r)
+
+    # send direct JPG
+    return Response( jpg.tobytes() , direct_passthrough= True)
+    # rather than <img />
+    return Response(b'--frame\r\n' b'Content-Type: image/jpeg\r\n\r\n' + jpg.tobytes() + b'\r\n\r\n', mimetype='multipart/x-mixed-replace; boundary=frame')
+
+
 
 @app.route('/background')
 @auth.login_required
 def background():
-    global  save_bg, frame_bg, frame_bg2, frame_mask, frame_mask_inv #, BGFILE
+    global  save_bg, frame_bg, frame_bg2, save_fg, frame_fg, frame_fg2, frame_mask, frame_mask_inv #, BGFILE
+
+
     #if not(frame_bg is None):
     #    # print(frame_bg, "BGFRAME")
     #    # # frame = cv2.imdecode(frame_bg, cv2.IMREAD_COLOR)
@@ -595,7 +663,8 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
     MAY do modifications per USER ! BUT any fraME MOD => IS SENT TO ALL!
     can send only some frames
     """
-    global save_bg, frame_bg, frame_bg2, frame_mask, frame_mask_inv
+    global  save_bg, frame_bg, frame_bg2, save_fg, frame_fg, frame_fg2, frame_mask, frame_mask_inv #, BGFILE
+
     print("D... entered gen, camera = ", camera)
     framecnt = 0
     framecnttrue = 0
